"""This module provides a simple way to compute the interpolation of
a Function (discrete or user-defined) onto a finite element space."""

__author__ = "Anders Logg (logg@simula.no)"
__date__ = "2008-10-06 -- 2009-02-16"
__copyright__ = "Copyright (C) 2008 Anders Logg"
__license__  = "GNU LGPL Version 2.1"

# Modified by Johan Hake, 2009.

__all__ = ['interpolate']

# Import SWIG-generated extension module (DOLFIN C++)
import cpp

# Local imports
from function import *

def interpolate(v, V):
    """Return interpolation of given function v onto the finite element space V.
    Example usage:

        V = FunctionSpace(mesh, "Lagrange", 1)

        Pv = interpolate(v, V)

    This is useful for post-processing functions which are not readily
    handled by visualization tools (such as for example discontinuous
    functions)."""

    # Check arguments
    if not isinstance(v, cpp.Function):
        cpp.error("Illegal function for interpolation, not a Function: " + str(v))
    if not isinstance(V, cpp.FunctionSpace):
        cpp.error("Illegal function space for interpolation, not a FunctionSpace: " + str(v))

    # Compute interpolation
    Pv = Function(V)
    v.interpolate(Pv.vector(), V)

    return Pv
